@@ -20,11 +20,11 @@
 ## along with adcc. If not, see <http://www.gnu.org/licenses/>.
 ##
 ## ---------------------------------------------------------------------
+from libadcc import amplitude_vector_enforce_spin_kind
+
 from adcc import evaluate
 from adcc.AmplitudeVector import AmplitudeVector
 
-from libadcc import amplitude_vector_enforce_spin_kind
-
 # TODO
 #    This interface is not that great and leads to duplicate information
 #    (e.g. once for setting up the guesses and once for setting up the
@@ -61,7 +61,7 @@ class IndexSymmetrisation():
             if not isinstance(vec, AmplitudeVector):
                 raise TypeError("new_vectors has to be an "
                                 "iterable of AmplitudeVector")
-            for b in vec.blocks:
+            for b in vec.blocks_ph:
                 if b not in self.symmetrisation_functions:
                     continue
                 vec[b] = evaluate(self.symmetrisation_functions[b](vec[b]))
@@ -87,11 +87,13 @@ class IndexSpinSymmetrisation(IndexSymmetrisation):
         for vec in new_vectors:
             # Only work on the doubles part
             # the other blocks are not yet implemented
-            # or nothing needs to be done ("s" block)
-            [amplitude_vector_enforce_spin_kind(vec[b], b,
-                                                self.enforce_spin_kind)
-             for b in vec.blocks if b in ["d"]
-             ]
+            # or nothing needs to be done ("ph" block)
+            if "pphh" in vec.blocks_ph:
+                # TODO: Note that the "d" is needed here because the C++ side
+                #       does not yet understand ph and pphh
+                amplitude_vector_enforce_spin_kind(
+                    vec.pphh, "d", self.enforce_spin_kind
+                )
         return new_vectors
 
 
