@@ -49,9 +49,7 @@ class JacobiPreconditioner:
             raise TypeError("Only an AdcMatrixlike may be used with this "
                             "preconditioner for now.")
 
-        self.diagonal = AmplitudeVector(*tuple(
-            adcmatrix.diagonal(block) for block in adcmatrix.blocks
-        ))
+        self.diagonal = adcmatrix.diagonal()
         self.shifts = shifts
 
     def update_shifts(self, shifts):
@@ -63,18 +61,6 @@ class JacobiPreconditioner:
         of the passed vectors.
         """
         self.shifts = shifts
-        # TODO: this seems to be implemented?
-        # if isinstance(shifts, (float, np.number)):
-        #     raise NotImplementedError("Using only a single common shift is "
-        #                               "not implemented at the moment.")
-
-    def __compute_single_matvec(self, shift, invec):
-        eps = 1e-6  # Epsilon factor to make sure that 1 / (shift - diagonal)
-        #             does not become ill-conditioned as soon as the shift
-        #             approaches the actual diagonal values (which are the
-        #             eigenvalues for the ADC(2) doubles part if the coupling
-        #             block are absent)
-        return invec / (self.diagonal - (shift - eps))
 
     def apply(self, invecs):
         if isinstance(invecs, AmplitudeVector):
@@ -82,7 +68,7 @@ class JacobiPreconditioner:
                 raise TypeError("Can only apply JacobiPreconditioner "
                                 "to a single vector if shifts is "
                                 "only a single number.")
-            return self.__compute_single_matvec(self.shifts, invecs)
+            return invecs / (self.diagonal - self.shifts)
         elif isinstance(invecs, list):
             if len(self.shifts) != len(invecs):
                 raise ValueError("Number of vectors passed does not agree "
@@ -90,7 +76,7 @@ class JacobiPreconditioner:
                                  "precoditioner. Update using the "
                                  "'update_shifts' method.")
 
-            return [self.__compute_single_matvec(self.shifts[i], v)
+            return [v / (self.diagonal - self.shifts[i])
                     for i, v in enumerate(invecs)]
         else:
             raise TypeError("Input type not understood: " + str(type(invecs)))
